{% extends 'main/base.html' %}

{% block title %} :: {% with 'true' as striptags %}{% include 'generic_views/calculate_form_title.html' %}{% endwith %}{% endblock %}

{% block content %}
    {% include 'generic_views/generic_form_subtemplate.html' %}
{% endblock %}
