{% extends 'main/base.html' %}

{% load i18n %}

{% block title %}:: {% trans 'Search results' %}{% endblock %}

{% block content %}
    {% with 'get' as submit_method %}
    {% with form_title as title %}
        {% include 'generic_views/generic_form_subtemplate.html' %}
    {% endwith %}
    {% endwith %}

    {% if query_string %}
        {% if not found_entries %}
            <h2 class='title'>{% trans 'No results found' %}</h2>
        {% else %}
            {% include 'generic_views/generic_list_subtemplate.html' %}
        {% endif %}
    {% endif %}
{% endblock %}


