{% load i18n %}

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
    "http://www.w3.org/TR/html4/loose.dtd">
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

        <link href="/site_media/css/pisa.css" rel="stylesheet" type="text/css" media="screen" />
        <link href="/site_media/css/pisa.css" rel="stylesheet" type="text/css" media="print" />
    </head>
    <body>


<h1>{% trans 'User assets report' %}</h1>
{% block content %}
<br/ >
<h2>Equipo asignado a: {{ object }}</h2>
        <table style="border: 1px solid black; vertical-align: center; text-align:center; width:100%;">
                <thead>
                    <strong><tr>
                        <td>{% trans 'ASSET NUMBER' %}</td>
                        <td>{% trans 'DESCRIPTION' %}</td>
                        <td>{% trans 'LOCATION' %}</td>
                        <td>{% trans 'ASSIGNED TO' %}</td>
                        <td>{% trans 'NOTES' %}</td>
                    </tr></strong>
                </thead>
                <tbody>
                    {% for item in object.inventory.all %}
                        <tr>
                            <td>{{ item.property_number }}</td>
                            <td>{{ item.item_template.description }}</td>
                            <td>{{ item.location }}</td>
                            <td>{{ object }}</td>
                            <td>&nbsp;{{ item.notes }}</td>
                        </tr>
                    {% endfor %}
                </tbody>
            </table>
{% endblock %}

<div id="footerblock">
{%block pager %}
    <pdf:pagenumber>
{%endblock%}
</div>
</body>
</html>
