{% extends 'main/base.html' %}

{% load project_tags %}

{% load i18n %}
{% load static %}

{% block content %}
    <div class="content">
        <div class="tc"><h1>{% project_name %}</h1></div>
        <div class="tc"><img src="{% static 'main/images/1269206_36297494-resized.jpg' %}" /></div>
    </div>
{% endblock %}

{% block footer %}
    <div id="footer">
        <div class="block">
            <p>{% trans 'Copyright &copy; 2007 Roberto Rosario.' %}</p>
        </div>
    </div>
{% endblock %}
