{% extends 'main/base.html' %}

{% load i18n %}
{% load static %}

{% block javascript %}
    <script type="text/javascript" src="{% static 'photos/packages/jquery-lightbox-0.5/js/jquery.lightbox-0.5.js' %}"></script>
    <link rel="stylesheet" type="text/css" href="{% static 'photos/packages/jquery-lightbox-0.5/css/jquery.lightbox-0.5.css' %}" media="screen" />

    <script type="text/javascript">
        $(function() {
            $('.gallery a').lightBox();

            $(".form_w_progress").submit(function() {
                $('#photo-upload').fadeIn('slow');
                $('input:submit', this).attr("value", "{% trans 'Please wait...' %}");
                $('input:submit', this).attr("disabled", "disabled");
                return true;
            });
        });
    </script>
{% endblock %}

{% block title %} :: {% trans 'Add / remove photos' %}{% endblock %}

{% block content %}
    {% include 'generic_views/generic_list_subtemplate.html' %}
{% endblock %}
