{% extends 'main/base.html' %}

{% load i18n %}

{% load project_tags %}

{% block title %} :: {% trans 'About this program' %}{% endblock %}

{% block content %}
    <div class="content">
        <h3 class="tc">
        {% project_name %}<br /><br />
        {% trans 'Free Open Source Inventory and Fixed Assets Control System' %}<br /><br />
        <a href="http://www.github.com/rosarior/django-inventory/">http://www.github.com/rosarior/django-inventory/</a><br /><br />
        </h3>
    </div>
{% endblock %}

{% block footer %}
    <div id="footer">
        <div class="block">
            <p>{% trans 'Copyright &copy; 2007 Roberto Rosario.' %}</p>
        </div>
    </div>
{% endblock %}
