{% load i18n %}

{% for link in object_navigation_links %}
    {% if as_li %}<li>{% endif %}
        <a href="{{ link.url }}">{% if link.famfam %}<span class="famfam active famfam-{{ link.famfam|default:'link' }}"></span>{% endif %}{{ link.text|capfirst }}{% if link.error %} - {{ link.error }}{% endif %}{% if link.active %}<span class="famfam active famfam-resultset_previous"></span>{% endif %}</a>{% if horizontal %}{% if not forloop.last %} | {% endif %}{% endif %}
    {% if as_li %}</li>{% endif %}    
{% endfor %}
