{% extends 'main/base.html' %}

{% load i18n %}

{% block title %}{% trans 'Page not found' %}{% endblock %}

{% block content %}
    <h1>{% trans 'Page not found' %}</h1>
    <p>{% trans 'Sorry, but the requested page could not be found.' %}</p>
{% endblock %}
